@@ -212,9 +212,13 @@ def build_a_status_from_row(obj):
     return result
     
 def build_settings_from_row(obj):
-    if obj==None:
-        return None
     result = {}
+    
+    if obj==None:
+        result["downpic"]="True"
+        result["updatenum"]="10"
+        return result
+        
     for att in SETTINGS_ATT_NAMES:
         try:
             result[att]=str(obj[att])
@@ -524,6 +528,9 @@ DROP TABLE IF EXISTS status;
 SQL_DROP_USER_TABLE="""
 DROP TABLE IF EXISTS user;
 """
+SQL_DROP_SETTINGS_TABLE="""
+DROP TABLE IF EXISTS settings;
+"""
 SQL_CREATE_ACCOUNT_TABLE="""
 CREATE TABLE [account]
 (
@@ -595,3 +602,11 @@ CREATE TABLE [user]
 [user_id] INTEGER PRIMARY KEY AUTOINCREMENT
 )
 """
+
+SQL_CREATE_SETTINGS_TABLE="""
+CREATE TABLE IF NOT EXISTS [settings]
+(
+[downpic] VARCHAR,
+[updatenum] VARCHAR
+)
+"""
