@@ -55,8 +55,11 @@ class MaoboApp(QApplication):
         self.timelineType=None
         self.accounts=self.controller.get_all_accounts()
         self.websites=self.controller.get_all_websites()
+        self.settings=self.controller.get_settings()
+        
         self.currentAccount=None
 
+        self.create_default_window()
         self.create_accounts_window()
         self.create_menus_window()
         self.create_timeline_window()
@@ -65,8 +68,21 @@ class MaoboApp(QApplication):
         self.accountsManaForm=None
         self.newAccountForm=None
 
-        self.accountsWin.show()
-
+        if len(self.accounts)==0:
+            self.defaultWin.show()
+        else:
+            self.accountsWin.show()
+            
+        
+    def create_default_window(self):
+        self.defaultWin=DefaultWindow(None)
+        accountsManaAction = self.create_action(unicode("账户管理"), self.show_accounts_mana_form)
+        settingAction=self.create_action(unicode("微博设置"), self.show_setting_form)
+        delcacheAction=self.create_action(unicode("清理缓存"), self.delete_cache)
+        aboutAction=self.create_action(unicode("关于软件"), self.show_about_form)
+        self.menuBar=QMenuBar()
+        self.add_actions(self.menuBar, (accountsManaAction,settingAction,delcacheAction,aboutAction))
+        self.defaultWin.setMenuBar(self.menuBar)
 
     def create_accounts_window(self):
         self.accountsWin=AccountsWindow(None,self.accounts,self.websites)
@@ -74,16 +90,29 @@ class MaoboApp(QApplication):
                      SIGNAL("clicked(const QModelIndex&)"),
                      self.account_clicked)
         accountsManaAction = self.create_action(unicode("账户管理"), self.show_accounts_mana_form)
-        aboutAction=self.create_action(unicode("关于"), self.show_about_form)
+        settingAction=self.create_action(unicode("微博设置"), self.show_setting_form)
+        delcacheAction=self.create_action(unicode("清理缓存"), self.delete_cache)
+        aboutAction=self.create_action(unicode("关于软件"), self.show_about_form)
         self.menuBar=QMenuBar()
-        self.add_actions(self.menuBar, (accountsManaAction,aboutAction))
+        self.add_actions(self.menuBar, (accountsManaAction,settingAction,delcacheAction,aboutAction))
         self.accountsWin.setMenuBar(self.menuBar)
 
+    def delete_cache(self):
+        # delete cache images and data. befor 30 days.
+        
+        self.controller.del_status_by_cache()
+        
+        import os
+        os.system('find '+Utils.THUMBNAIL_DIR+' -mtime +7 | xargs rm -rf')
+        os.system('rm -rf '+Utils.LOG_FILE)
+        
+        self.show_notice("成功清理一周之前的图片、微博、以及日志数据缓存。")
+        
     def account_clicked(self,index):
         self.logger.debug("account_clicked")
         row=index.row()
         self.currentAccount=self.accounts[row]
-        print self.currentAccount
+        #print self.currentAccount
         
         if self.currentAccount["website"]==1:
             self.updater=self.updatersina
@@ -91,13 +120,13 @@ class MaoboApp(QApplication):
         else:
             self.updater=self.updaterqq
             self.sender=self.senderqq
-        
-	try:
-	    self.updater.OAuth(self.currentAccount["username"],self.currentAccount["password"])
-	    self.sender.OAuth(self.currentAccount["username"],self.currentAccount["password"])
-	except WeibopError,we:
-	    self.show_notice(we)
-        
+            
+        try:
+            self.updater.OAuth(self.currentAccount["username"],self.currentAccount["password"])
+            self.sender.OAuth(self.currentAccount["username"],self.currentAccount["password"])
+        except WeibopError,we:
+            self.show_notice(we)
+            
         self.logger.debug(self.currentAccount["username"]+" choosed.")
         self.menusWin.show()
 
@@ -119,8 +148,6 @@ class MaoboApp(QApplication):
         
         if value==Utils.NEW_A_STATUS:
             self.show_new_status_window()
-        #elif value==Utils.TIMELINE_TYPE_DM:
-        #    self.show_notice("私信功能由于官方权限限制，暂不开放。")
         else:
             self.timelineType=value
             self.show_timeline_window()
@@ -193,22 +220,21 @@ class MaoboApp(QApplication):
                     self.logger.debug("updater is running!")
                     self.show_notice("后台运行中，请稍候重试")
                     return
-                        
-                        
+                
                 if self.currentAccount["website"]==1:
                     maxStatus=self.statuses[row-1]
                     sinceStatus=self.statuses[row+1]
-                    maxId=maxStatus["id"]
+                    maxId=maxStatus["id"]-1
                     sinceId=sinceStatus["id"]
                     self.currentOpe=self.gapOpe
                     self.gapRow=row
-                    self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,maxId)
+                    self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,maxId,self.settings["updatenum"],self.settings["downpic"])
                 else:
-                    tmpStatus=self.statuses[row+1]
+                    tmpStatus=self.statuses[row-1]
                     pagetime=tmpStatus["bmiddle_pic"]
                     self.currentOpe=self.gapOpe
                     self.gapRow=row
-                    self.updater.initialize(self.currentAccount["id"],self.timelineType,2,pagetime,1)
+                    self.updater.initialize(self.currentAccount["id"],self.timelineType,1,pagetime,self.settings["updatenum"],self.settings["downpic"])
                 
 #                try:
 #                    self.updater.basicAuth(Utils.APP_KEY,self.currentAccount["username"],self.currentAccount["password"])
@@ -244,59 +270,78 @@ class MaoboApp(QApplication):
                 sinceId=latestStatus["id"]
                 self.logger.debug("sinceId:"+str(sinceId))
             
-            self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,None)
+            self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,None,self.settings["updatenum"],self.settings["downpic"])
         else:
     	    pageflag=0
     	    pagetime=0
     	    
-    	    if len(self.statuses)>1:
-    	        latestStatus=self.statuses[1]
-    	        lasetime=int(latestStatus["bmiddle_pic"])
+    	    # rem for binkcn 0926
+    	    #if len(self.statuses)>1:
+    	    #    latestStatus=self.statuses[1]
+    	    #    lasetime=int(latestStatus["bmiddle_pic"])
     	        
-    	        import time
-    	        nowtime = int(time.time())
-    	        timediff = nowtime - lasetime
-    	        if timediff <= 86400:
-    	            pageflag=2
-    	            pagetime=lasetime
+    	        #import time
+    	        #nowtime = int(time.time())
+    	        #timediff = nowtime - lasetime
+    	        #if timediff <= 86400:
+    	        #    pageflag=2
+    	        #    pagetime=lasetime
     	            
-            self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,10)
+            self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,self.settings["updatenum"],self.settings["downpic"])
         
-#        try:
-#            self.updater.basicAuth(Utils.APP_KEY,self.currentAccount["username"],self.currentAccount["password"])
-#        except WeibopError,we:
-#            self.show_notice(we)
         self.show_notice("更新中...")
         self.set_windows_status(1)
         self.updater.start()
         
-
+    def checkExits(self, newsStatus):
+        for tmpStatus in self.statuses:
+            if len(tmpStatus)>5:
+                #print "=========================================="
+                #print "Debug!"
+                #print str(newsStatus["id"]) + " -> " + str(tmpStatus["id"])
+                if tmpStatus["id"]==newsStatus["id"]:
+                    #print "Remove!"
+                    return 1
+                
+        return 0
+    
     def update_finished(self,completed):
         self.logger.debug("update_finished")
         self.set_windows_status(0)
         newStatuses=self.updater.timeline
-
+        
+        # parse remove exist. for tencent.
+        if self.currentAccount["website"] == 2:
+            tmpStatuses = []
+            for newStatus in newStatuses:
+                tmpStatuses.append(newStatus)
+            
+            for newStatus in tmpStatuses:
+                if self.checkExits(newStatus)==1:
+                    newStatuses.remove(newStatus)
+        
         if self.currentOpe==self.updateOpe:
             #update the lastUpdateTime for the updateOpe and account
             now=datetime.now()
             self.currentAccount=Utils.set_last_update_time_by_timeline_type(self.currentAccount, self.timelineType, now)
             self.controller.save_an_account(self.currentAccount)
             self.updateOpe["name"]="Click to update"
-            self.updateOpe["lastUpdated"]=Utils.get_last_update_time_by_timeline_type(self.currentAccount,
-                                                                                  self.timelineType)
+            self.updateOpe["lastUpdated"]=Utils.get_last_update_time_by_timeline_type(self.currentAccount, self.timelineType)
         elif self.currentOpe==self.moreOpe:
             self.moreOpe["name"]="Click to load more"
         
         if newStatuses!=None and len(newStatuses)>0:
             if self.currentOpe==self.updateOpe:
                 self.statuses.remove(self.updateOpe)
-
-                if len(newStatuses)==20 and len(self.statuses)>1:
+                
+                if len(newStatuses)==int(self.settings["updatenum"]) and len(self.statuses)>1:
                     self.logger.debug("add a gap status")
+                    
                     gapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
                     gapStatus["id"]=newStatuses[-1]["id"]-1
+                    gapStatus["created_at"]=self.getMinCreatedAt(newStatuses,self.currentAccount["website"])
                     newStatuses.append(gapStatus)
-
+                
                 self.controller.save_statuses(self.currentAccount["id"],newStatuses,self.timelineType)
 
                 if len(self.statuses)==0:
@@ -318,23 +363,17 @@ class MaoboApp(QApplication):
                     self.statuses.append(self.moreOpe)
                     self.timelineWin.load_statuses(self.statuses)
             elif self.currentOpe==self.gapOpe:
-                #there must be a repeat one:maxId, remove it.
                 repeatOne=newStatuses[0]
-                newStatuses.remove(repeatOne)
-#                if len(newStatuses)>0:
-                #first remove the old gap
                 row=self.gapRow
                 gapStatus=self.statuses[row]
-                print "a"
-                print row
-                print gapStatus
-                self.controller.del_status_by_id(1,gapStatus["id"])
-                if len(newStatuses)==20-1:
-                    #if the len is 20,maybe there are more statuses, so need a gap here.
+                self.controller.del_status_by_id(self.currentAccount["id"],gapStatus["id"])
+                if len(newStatuses)==int(self.settings["updatenum"]):
                     self.logger.debug("add a gap status")
-                    newGapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
-                    newGapStatus["id"]=newStatuses[-1]["id"]-1
-                    newStatuses.append(newGapStatus)
+                    
+                    newgapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
+                    newgapStatus["id"]=newStatuses[-1]["id"]-1
+                    newgapStatus["created_at"]=self.getMinCreatedAt(newStatuses,self.currentAccount["website"])
+                    newStatuses.append(newgapStatus)
                 self.controller.save_statuses(self.currentAccount["id"],newStatuses,self.timelineType)
 
                 #remove the old gap and insert the new ones into the gap.
@@ -343,10 +382,31 @@ class MaoboApp(QApplication):
                 for newOne in newStatuses:
                     i+=1
                     self.statuses.insert(row+i,newOne)
+                
                 self.timelineWin.load_statuses(self.statuses)
 
                         
         self.currentOpe=None
+        
+    def getMinCreatedAt(self, newstatuses, website):
+        mincreatedat = None
+        
+        if website==1:
+            minid = 8353251501876959
+            for newstatus in newstatuses:
+                timenum = int(newstatus["id"])
+                if timenum < minid:
+                    minid = timenum
+                    mincreatedat = newstatus["created_at"]
+        else:
+            mintimenum = 3316874565
+            for newstatus in newstatuses:
+                timenum = int(newstatus["bmiddle_pic"])
+                if timenum < mintimenum:
+                    mintimenum = timenum
+                    mincreatedat = newstatus["created_at"]
+                
+        return mincreatedat
 
     def load_more_timeline(self):
         self.logger.debug("load_more_timeline")
@@ -372,13 +432,12 @@ class MaoboApp(QApplication):
                 oldestStatus=self.statuses[-2]
                 maxId=oldestStatus["id"]
                 self.logger.debug("maxId:"+str(maxId))
-                self.updater.initialize(self.currentAccount["id"],self.timelineType,None,maxId)
+                self.updater.initialize(self.currentAccount["id"],self.timelineType,None,maxId,self.settings["updatenum"],self.settings["downpic"])
             else:
                 oldestStatus=self.statuses[-2]
                 pagetime=oldestStatus["bmiddle_pic"]
     	        pageflag=1
-        	    
-                self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,10)
+                self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,self.settings["updatenum"],self.settings["downpic"])
             
             
 #            try:
@@ -414,6 +473,7 @@ class MaoboApp(QApplication):
                      SIGNAL("clicked()"),
                      self.send_a_status)
 
+
     def show_new_status_window(self,status=None):
         self.create_new_status_window(self.menusWin)
         self.newStatusWin.load_status()
@@ -521,6 +581,8 @@ class MaoboApp(QApplication):
             self.controller.save_an_account(account)
 
             self.newAccountForm.hide()
+            self.defaultWin.hide()
+            self.accountsWin.show()
             self.show_accounts_mana_form()
             self.accountsModel=AccountsModel(self.accounts,self.websites)
             self.accountsWin.accountsListView.setModel(self.accountsModel)
@@ -558,7 +620,20 @@ class MaoboApp(QApplication):
         self.accountsModel=AccountsModel(self.accounts,self.websites)
         self.accountsWin.accountsListView.setModel(self.accountsModel)
 
+    def show_setting_form(self):
+        self.settingForm=SettingForm(self.accountsWin, self.settings)
+        self.connect(self.settingForm.confirmButton,
+                     SIGNAL("clicked()"),
+                     self.save_settings)
+        self.settingForm.show()
         
+    def save_settings(self):
+        settings=self.settingForm.output_account(self.show_notice)
+        if settings!=None:
+            settings = self.controller.save_settings(settings)
+            if settings!=None:
+                self.settings=settings
+                self.show_notice("成功保存微博设置")
 
     def show_about_form(self):
         aboutForm=AboutForm(self.accountsWin)
@@ -608,7 +683,8 @@ class MaoboApp(QApplication):
                 target.addSeparator()
             else:
                 target.addAction(action)
-
+                
+        
 def main():
     dir=Utils.DATA_FILE_PATH
     if os.access(dir, os.W_OK) == 0:
